@@ -25,7 +25,7 @@ boolector = SMTSolver {
          , engine       = standardEngine "SBV_BOOLECTOR" "SBV_BOOLECTOR_OPTIONS" addTimeOut standardModel
          , capabilities = SolverCapabilities {
                                 capSolverName              = "Boolector"
-                              , mbDefaultLogic             = Nothing
+                              , mbDefaultLogic             = const Nothing
                               , supportsMacros             = False
                               , supportsProduceModels      = True
                               , supportsQuantifiers        = False
