@@ -27,7 +27,7 @@ cvc4 = SMTSolver {
          , engine       = standardEngine "SBV_CVC4" "SBV_CVC4_OPTIONS" addTimeOut standardModel
          , capabilities = SolverCapabilities {
                                 capSolverName              = "CVC4"
-                              , mbDefaultLogic             = Just "ALL_SUPPORTED"  -- CVC4 is not happy if we don't set the logic, so fall-back to this if necessary
+                              , mbDefaultLogic             = const (Just "ALL_SUPPORTED")  -- CVC4 is not happy if we don't set the logic, so fall-back to this if necessary
                               , supportsMacros             = True
                               , supportsProduceModels      = True
                               , supportsQuantifiers        = True
