@@ -27,7 +27,7 @@ mathSAT = SMTSolver {
          , engine       = standardEngine "SBV_MATHSAT" "SBV_MATHSAT_OPTIONS" addTimeOut standardModel
          , capabilities = SolverCapabilities {
                                 capSolverName              = "MathSAT"
-                              , mbDefaultLogic             = Nothing
+                              , mbDefaultLogic             = const Nothing
                               , supportsMacros             = False
                               , supportsProduceModels      = True
                               , supportsQuantifiers        = True
