@@ -11,6 +11,7 @@
 
 {-# LANGUAGE DeriveDataTypeable  #-}
 {-# LANGUAGE ScopedTypeVariables #-}
+
 module TestSuite.Uninterpreted.Sort where
 
 import Data.SBV
@@ -23,7 +24,7 @@ testSuite = mkTestSuite $ \_ -> test [
   "unint-sort" ~: assert . (==4) . length . (extractModels :: AllSatResult -> [L]) =<< allSat p0
  ]
 
-data L = Nil | Cons Int L deriving (Eq, Ord, Data, Typeable, Read, Show)
+data L = Nil | Cons Int L deriving (Eq, Ord, Data, Read, Show)
 instance SymWord L
 instance HasKind L
 instance SatModel L where
